==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetVirtualNodeSpecListenerConnectionPool.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property grpcs
 * @property http2s
 * @property https
 * @property tcps
 */
public data class GetVirtualNodeSpecListenerConnectionPool(
    public val grpcs: List<GetVirtualNodeSpecListenerConnectionPoolGrpc>,
    public val http2s: List<GetVirtualNodeSpecListenerConnectionPoolHttp2>,
    public val https: List<GetVirtualNodeSpecListenerConnectionPoolHttp>,
    public val tcps: List<GetVirtualNodeSpecListenerConnectionPoolTcp>,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetVirtualNodeSpecListenerConnectionPool):
            GetVirtualNodeSpecListenerConnectionPool = GetVirtualNodeSpecListenerConnectionPool(
            grpcs = javaType.grpcs().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecListenerConnectionPoolGrpc.Companion.toKotlin(args0)
                })
            }),
            http2s = javaType.http2s().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecListenerConnectionPoolHttp2.Companion.toKotlin(args0)
                })
            }),
            https = javaType.https().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecListenerConnectionPoolHttp.Companion.toKotlin(args0)
                })
            }),
            tcps = javaType.tcps().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecListenerConnectionPoolTcp.Companion.toKotlin(args0)
                })
            }),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetVirtualNodeSpecListenerConnectionPool.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property grpcs
 * @property http2s
 * @property https
 * @property tcps
 */
public data class GetVirtualNodeSpecListenerConnectionPool(
    public val grpcs: List<GetVirtualNodeSpecListenerConnectionPoolGrpc>,
    public val http2s: List<GetVirtualNodeSpecListenerConnectionPoolHttp2>,
    public val https: List<GetVirtualNodeSpecListenerConnectionPoolHttp>,
    public val tcps: List<GetVirtualNodeSpecListenerConnectionPoolTcp>,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetVirtualNodeSpecListenerConnectionPool): GetVirtualNodeSpecListenerConnectionPool = GetVirtualNodeSpecListenerConnectionPool(
            grpcs = javaType.grpcs().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecListenerConnectionPoolGrpc.Companion.toKotlin(args0)
                })
            }),
            http2s = javaType.http2s().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecListenerConnectionPoolHttp2.Companion.toKotlin(args0)
                })
            }),
            https = javaType.https().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecListenerConnectionPoolHttp.Companion.toKotlin(args0)
                })
            }),
            tcps = javaType.tcps().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecListenerConnectionPoolTcp.Companion.toKotlin(args0)
                })
            }),
        )
    }
}
